@@ -2,7 +2,6 @@
 """GitHub class file."""
 
 import datetime
-# import logging
 import requests
 
 
@@ -58,6 +57,11 @@ class GitHub(object):
         from bits.github.firestore import Firestore
         return Firestore(auth, self)
 
+    def helpers(self, auth):
+        """Return a Firestore instance."""
+        from bits.github.helpers import Helpers
+        return Helpers(auth, self)
+
     def sync(self, auth):
         """Return an Update instance."""
         from bits.github.sync import Sync
@@ -95,6 +99,10 @@ class GitHub(object):
 
     def get_modified(self, url, headers={}, params={}, etag=None, last_modified=None):
         """Return a response from a GET call if modified, otherwise return False."""
+        # reset the headers from any previous requests
+        headers['If-None-Match'] = None
+        headers['If-Modified-Since'] = None
+
         # add etag and last-modified request headers
         if etag:
             headers['If-None-Match'] = etag
@@ -102,7 +110,7 @@ class GitHub(object):
             headers['If-Modified-Since'] = last_modified
 
         # get response
-        response = self.get(url, headers=headers)
+        response = self.get(url, headers=headers, params=params)
 
         # check if not changed
         if response.status_code == 304:
